@@ -32,7 +32,6 @@
 #include <kmimetypefactory_p.h>
 #include <kservicefactory_p.h>
 #include <kservicegroupfactory_p.h>
-#include <stdlib.h>
 
 #include "kbuildsycoca_p.h"
 #include "ksycocadevices_p.h"
@@ -42,14 +41,14 @@
 #include <utime.h>
 #endif
 
-/**
+/*
  * Sycoca file version number.
  * If the existing file is outdated, it will not get read
  * but instead we'll regenerate a new one.
  * However running apps should still be able to read it, so
  * only add to the data, never remove/modify.
  */
-#define KSYCOCA_VERSION 305
+#define KSYCOCA_VERSION 306
 
 #if HAVE_MADVISE || HAVE_MMAP
 #include <sys/mman.h> // This #include was checked when looking for posix_madvise
@@ -660,7 +659,7 @@ bool KSycocaPrivate::needsRebuild()
     // ensure files are ordered so next comparison works
     files.sort();
     // to cover cases when extra files were added
-    return extraFiles.keys() != files;
+    return extraFiles.keys() != files; // clazy:exclude=container-anti-pattern
 }
 
 bool KSycocaPrivate::buildSycoca()
